# hclib

![PyPI](https://img.shields.io/pypi/v/hclib.svg)

This is a wrapper to connect to [hack.chat](https://github.com/hack-chat/main) instances.

# Documentation

1. Start the REPL:
    - Windows: `python`
    - Other: `python3`
1. View:
    ```python
    import hclib
    help(hclib)
    ```

# License

This project is under the [MIT license](LICENSE).
